(function () {
    'use strict';
    //詳細画面の表示後イベント
    kintone.events.on('app.record.detail.show', function (event) {
        var url = '{URL}';
        var krewdataAppUrl = '{KREWDATA_APP_URL}';
        var serialNumber = '{SERIAL_NUMBER}';
        // ご利用の環境に合わせて上記の {URL}、{KREWDATA_APP_URL}、{SERIAL_NUMBER} に値を設定してください。
        //  {URL}               ：実行単位のURL
        //  {KREWDATA_APP_URL}  ：krewData専用アプリのURL
        //  {SERIAL_NUMBER}     ：リアルタイム実行プランのシリアルナンバー
        // (設定例)
        //  var url = 'https://api.krewdata.grapecity.com/trigger/v1/abcdefghijklmn';
        //  var krewdataAppUrl = 'https://yourdomain.cybozu.com/k/123';
        //  var serialNumber = 'abcdef-jklmno-pqrstu-xyz123-456789';

        // 関連レコード一覧の下に「発注」ボタンを配置
        var orderButton = document.createElement('button');
        orderButton.id = 'order_button';
        orderButton.innerText = '発注';
        orderButton.onclick = async(buttonEvent) => {
            if (window.confirm('発注を実行しますか？')) {
                // Request Access Token
                var tokenBody = {
                    'krewdataAppUrl': krewdataAppUrl,
                    // base-64 エンコード
                    'serialNumber': window.btoa(serialNumber)
                };
                // アクセストークンの取得
                var tokenResponse = await sendRequest('token', url, tokenBody);
                console.log(JSON.stringify(tokenResponse));
                // アクセストークンを正常取得できた場合は、集計処理を呼び出し
                if (tokenResponse.code == 200) {
                    var accessToken = tokenResponse.accessToken;
                    // リクエストパラメータの設定
                    var runBody = {
                        'accessToken': accessToken,
                        'user': kintone.getLoginUser().code,
                        'appId': event.appId.toString(),
                        'record': event.record
                    };
                    // krewDataの呼び出し
                    var runResponse = await sendRequest('run', url, runBody);
                    console.log(JSON.stringify(runResponse));
                    // 呼び出しの成功
                    if (runResponse.code == 200) {
                        var taskId = runResponse.taskId;
                        var statusBody = {
                            'accessToken': accessToken,
                            'taskId': taskId
                        };
                        var statusInterval = setInterval(async function () {
                            // 実行状況の確認
                            var statusResponse = await sendRequest('status', url, statusBody);
                            console.log(JSON.stringify(statusResponse));
                            if (statusResponse.taskStatus == 'Success') {
                                if (statusResponse.code == 200){
                                    // 実行の成功
                                    window.alert('処理が完了しました！');
                                }
                                clearInterval(statusInterval);
                            }
                            else if (statusResponse.taskStatus == 'Failure'){
                                // 実行の成功
                                window.alert('処理が失敗しました！');
                                clearInterval(statusInterval);
                            }
                        }, 5000); // 5sec
                    }
                    else {
                        // 呼び出しの失敗
                        window.alert(runResponse.description);
                    }
                }
                else {
                    // アクセストークン取得失敗のメッセージ
                    window.alert(tokenResponse.description);
                }
            }
        }
        kintone.app.record.getSpaceElement('orderButton').appendChild(orderButton);
    });
})();

function sendRequest(api, url, body) {
    var _kintone = kintone;
    var uri = url + '/' + api;
    return new _kintone.Promise(function (resolve, reject) {
        _kintone.proxy(uri, 'POST', {
            'Content-Type': 'application/json;charset=UTF-8'
        }, body, function (body, status, headers) {
            resolve(JSON.parse(body));
        }, function (error) {
            reject(error);
        });
    });
}
